Needed apps to make this app work. <br>
1- Tkinter <br>
2- Python3 <br>
3- Xscreensaver <br>
4- Xterm is needed for installer/uninstaller <br>
<br>
<br>
*This version is for only Void(Runit) Linux supported <br> <br>
* elogind needs to be installed, it may be already installed. <br>
*İf u install with PİP, app is installed at ~/.local/lib/python3.9/ <br>
*Hidden files can be revealed by CTRL+H, files start with . are hidden.
* # pip show Kyak2-Void to show all info.
*İnstaller is included it also uninstalls.